@@ -18,7 +18,7 @@ use IPC::Open3;
 use Symbol 'gensym';
 use Carp;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 my $logger = get_logger();
 
 sub _acquire_tar_info {
@@ -61,18 +61,15 @@ sub _setup_mswin {
     my $self = shift;
 
     # bsdtar is always preferred on Windows
-    my $tar = which('bsdtar');
+    my $tar_path = which('bsdtar');
+    $tar_path = which('tar') unless ( defined($tar_path) );
 
-    if ( $tar eq '' ) {
-        $tar = which('tar');
+    if ( $tar_path =~ /\s/ ) {
+
+        # double quoting will be required is there is a space
+        $tar_path = qq($tar_path);
     }
-
-    if ( $tar =~ /\s/ ) {
-
-        # double quoting might be required on MS Windows
-        $tar = qq($tar);
-    }
-    $self->{tar} = $tar;
+    $self->{tar} = $tar_path;
 }
 
 sub new {
@@ -971,7 +968,7 @@ newlines.
 
 Support on Microsoft Windows is limited.
 
-Version below Windows 10 will not be supported.
+Version below Windows 10 will not be supported for desktops, and for servers from Windows 2012 and above.
 
 The GNU C<tar.exe> program doesn't work properly with the current interface of Archive::Tar::Wrapper.
 You must use the C<bsdtar.exe> and make sure it appears first in the C<PATH> environment variable than
